@@ -136,7 +136,7 @@ createIntamapObject = function(observations, obsChar, formulaString, predictionL
   	# EJP:
     #if (require(maptools)) object$boundaries = readShapePoly(boundFile) else
     #  warning("maptools not installed, not able to read boundaries")
-	  object$boundaries = rgdal::readOGR(".", boundFile)
+	  object$boundaries = readOGR(".", boundFile)
   }
   if (!missing(boundaryLines)) {
     object$boundaryLines = boundaryLines
@@ -232,10 +232,10 @@ conformProjections = function(object) {
   if (require(rgdal)) {
     if ("intCRS"%in% names(object)) {
       intCRS = object$intCRS
-    } else if (rgdal::CRSargs(CRS(obsCRS)) == rgdal::CRSargs(CRS(predCRS)) && !length(grep("longlat",obsCRS)) >0) {
-      intCRS = rgdal::CRSargs(CRS(obsCRS))
+    } else if (CRSargs(CRS(obsCRS)) == CRSargs(CRS(predCRS)) && !length(grep("longlat",obsCRS)) >0) {
+      intCRS = CRSargs(CRS(obsCRS))
     } else {
-      if ("targetCRS" %in% names(object) && !length(grep("longlat",rgdal::CRSargs(CRS(object$targetCRS)))) > 0) {
+      if ("targetCRS" %in% names(object) && !length(grep("longlat",CRSargs(CRS(object$targetCRS)))) > 0) {
         targetCRS = object$targetCRS
         intCRS = targetCRS
       } else {
@@ -252,15 +252,15 @@ conformProjections = function(object) {
         }
       }
     }
-    if (rgdal::CRSargs(CRS(obsCRS)) != rgdal::CRSargs(CRS(intCRS))) 
-       object$observations = rgdal::spTransform(observations,CRS(intCRS))
-    if (rgdal::CRSargs(CRS(predCRS)) != rgdal::CRSargs(CRS(intCRS))) 
-      object$predictionLocations = rgdal::spTransform(predictionLocations,CRS(intCRS))
+    if (CRSargs(CRS(obsCRS)) != CRSargs(CRS(intCRS))) 
+       object$observations = spTransform(observations,CRS(intCRS))
+    if (CRSargs(CRS(predCRS)) != CRSargs(CRS(intCRS))) 
+      object$predictionLocations = spTransform(predictionLocations,CRS(intCRS))
     if (!is.null(object$boundaries)) {
     	boundaries = object$boundaries
       boundCRS = proj4string(object$boundaries)
-    	if (rgdal::CRSargs(CRS(boundCRS)) != rgdal::CRSargs(CRS(intCRS))) 
-      	object$boundaries = rgdal::spTransform(boundaries,CRS(intCRS))
+    	if (CRSargs(CRS(boundCRS)) != CRSargs(CRS(intCRS))) 
+      	object$boundaries = spTransform(boundaries,CRS(intCRS))
     }
     if (!intCRS %in% names(object)) object$intCRS = intCRS
   } else {
